==> artemis_ui_kit-0.0.1.tar.gz: lib/src/ArtemisDatePickerDialog.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'Consts.dart';

class ArtemisDatePickerDialog extends StatefulWidget {
  final DateTime? currentDate;

  const ArtemisDatePickerDialog({Key? key, this.currentDate}) : super(key: key);
  @override
  _ArtemisDatePickerDialogState createState() => _ArtemisDatePickerDialogState();
}

class _ArtemisDatePickerDialogState extends State<ArtemisDatePickerDialog> {
  late DateTime tmpDate;
  @override
  void initState() {
      tmpDate = widget.currentDate??DateTime.now();
    super.initState();
  }
  @override
  Widget build(BuildContext context) {
    return Dialog(
      child: Container(
        decoration: BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.only(
              topLeft: Radius.circular(25),
              topRight: Radius.circular(25),
            )),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Padding(
              padding: const EdgeInsets.only(left: 36, right: 12, top: 36, bottom: 24),
              child: Row(
                children: [
                  Text(
                    "Select Date",
                    style: TextStyle(fontWeight: FontWeight.bold,fontSize: 22),
                  ),
                  Spacer(),
                  IconButton(
                      onPressed: () => Navigator.pop(context),
                      icon: Icon(
                        Icons.close,
                        color: ArtemisColors.brownGrey,
                      )),
                ],
              ),
            ),
            Expanded(
              child: CupertinoDatePicker(
                mode: CupertinoDatePickerMode.date,
                initialDateTime: tmpDate,
                onDateTimeChanged: (DateTime date) {
                  setState(() {
                    tmpDate =date;
                  });
                },
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(bottom: 12.0, right: 36, top: 0),
              child: Column(
                children: [
                  Row(
                    children: [

                      Spacer(),
                      TextButton(
                        onPressed: () {
                          Navigator.pop(context);
                        },
                        child: Text("Cancel"),
                        style: TextButton.styleFrom(primary: ArtemisColors.brownGrey),
                      ),
                      SizedBox(
                        width: 24
                      ),
                      OutlinedButton(
                        onPressed:() {
                          Navigator.pop(context,tmpDate);
                        },
                        child: Text("Apply"),
                        style: OutlinedButton.styleFrom(
                            primary: ArtemisColors.darkMint,
                            side: BorderSide(
                                color:  ArtemisColors.darkMint,
                                width: 2)),
                      )
                    ],
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> artemis_ui_kit-0.0.12.tar.gz: lib/src/ArtemisDatePickerDialog.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'Consts.dart';

class ArtemisDatePickerDialog extends StatefulWidget {
  final DateTime? currentDate;

  const ArtemisDatePickerDialog({Key? key, this.currentDate}) : super(key: key);
  @override
  _ArtemisDatePickerDialogState createState() =>
      _ArtemisDatePickerDialogState();
}

class _ArtemisDatePickerDialogState extends State<ArtemisDatePickerDialog> {
  late DateTime tmpDate;
  @override
  void initState() {
    tmpDate = widget.currentDate ?? DateTime.now();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Dialog(
      child: Container(
        decoration: BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.only(
              topLeft: Radius.circular(25),
              topRight: Radius.circular(25),
            )),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Padding(
              padding: const EdgeInsets.only(
                  left: 36, right: 12, top: 36, bottom: 24),
              child: Row(
                children: [
                  Text(
                    "Select Date",
                    style: TextStyle(fontWeight: FontWeight.bold, fontSize: 22),
                  ),
                  Spacer(),
                  IconButton(
                      onPressed: () => Navigator.pop(context),
                      icon: Icon(
                        Icons.close,
                        color: ArtemisColors.brownGrey,
                      )),
                ],
              ),
            ),
            Expanded(
              child: CupertinoDatePicker(
                mode: CupertinoDatePickerMode.date,
                initialDateTime: tmpDate,
                onDateTimeChanged: (DateTime date) {
                  setState(() {
                    tmpDate = date;
                  });
                },
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(bottom: 12.0, right: 36, top: 0),
              child: Column(
                children: [
                  Row(
                    children: [
                      Spacer(),
                      TextButton(
                        onPressed: () {
                          Navigator.pop(context);
                        },
                        child: Text("Cancel"),
                        style: TextButton.styleFrom(
                            primary: ArtemisColors.brownGrey),
                      ),
                      SizedBox(width: 24),
                      OutlinedButton(
                        onPressed: () {
                          Navigator.pop(context, tmpDate);
                        },
                        child: Text("Apply"),
                        style: OutlinedButton.styleFrom(
                            primary: ArtemisColors.darkMint,
                            side: BorderSide(
                                color: ArtemisColors.darkMint, width: 2)),
                      )
                    ],
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
